@@ -1,6 +1,6 @@
 """
 ======================================================
-Monolayer (:mod:`graphenemodeling.graphene.monolayer`)
+Monolayer (:mod:`graphene.monolayer`)
 ======================================================
 
 Functions
@@ -27,7 +27,7 @@ Optical Properties
 
     graphene.monolayer.Polarizibility
     graphene.monolayer.OpticalConductivity
-
+    graphene.monolayer.FresnelReflection
 
 Plasmonics
 ----------
@@ -123,13 +123,13 @@ def Hamiltonian(k,model,g0prime=0):
     Parameters
     ----------
 
-    k:  array-like
+    k:  array-like, complex, rad/m
         Wavevector of carrier. Use complex ``k=kx + 1j*ky`` for 2D wavevectors.
 
     model:  string
             ``'LowEnergy'``, ``'FullTightBinding'``
 
-    g0prime:    scalar
+    g0prime:    scalar, J
         The particle-hole asymmetry parameter :math:`\\gamma_0'`. Typically :math:`0.02\\gamma_0\\leq\\gamma_0'\\leq 0.2\\gamma_0`.
 
     Returns
@@ -215,7 +215,7 @@ def CarrierDispersion(k,model,eh=1,g0prime=_c.g0prime):
     Parameters
     ----------
 
-    k:          array-like, complex
+    k:          array-like, complex, rad/m
                 Wavevector of Dirac fermion relative to K vector.
                 For 2D wavevectors, use :math:`k= k_x + i k_y`.
 
@@ -361,7 +361,7 @@ def CarrierDispersion(k,model,eh=1,g0prime=_c.g0prime):
 
     return dispersion
 
-def FermiWavenumber(eFermi,model,g0prime=_c.g0prime):
+def FermiWavenumber(FermiLevel,model,g0prime=_c.g0prime):
     '''
     The Fermi wavenumber, i.e. the wavenumber of the state at
     the Fermi energy.
@@ -369,9 +369,11 @@ def FermiWavenumber(eFermi,model,g0prime=_c.g0prime):
     Parameters
     ----------
 
-    eFermi:      array-like, Fermi level
+    FermiLevel: array-like, J
+                Fermi level
 
-    model:       'LowEnergy': Value gets derived from linear approximation of dispersion.
+    model:      string
+                'LowEnergy' or 'FullTightBinding'.
 
     Examples
     --------
@@ -380,26 +382,26 @@ def FermiWavenumber(eFermi,model,g0prime=_c.g0prime):
     >>> from graphenemodeling import graphene
     >>> from scipy.constants import elementary_charge as eV
     >>> mlg = graphene.Monolayer()
-    >>> eF = 0.4 * eV # Fermi level is 0.4 eV
-    >>> kF = mlg.FermiWavenumber(eF, model='LowEnergy')
+    >>> FermiLevel = 0.4 * eV
+    >>> kF = mlg.FermiWavenumber(FermiLevel, model='LowEnergy')
     >>> mlg.CarrierDispersion(kF,model='LowEnergy')/eV
     0.4
     '''
 
     if model == 'LowEnergy':
-        return np.abs(eFermi) / (sc.hbar*_c.vF)
+        return np.abs(FermiLevel) / (sc.hbar*_c.vF)
 
     if model == 'FullTightBinding':
         '''
         Need to finish off this code-finding procedure
         '''
-        eh = np.sign(eFermi)
+        eh = np.sign(FermiLevel)
 
         # f is zero when kf is correct value
-        f = lambda kf: eFermi - CarrierDispersion(kf, model='FullTightBinding',eh=eh,g0prime=g0prime)
+        f = lambda kf: FermiLevel - CarrierDispersion(kf, model='FullTightBinding',eh=eh,g0prime=g0prime)
 
         # Choose LowEnergy answer for initial starting point
-        kf0 = FermiWavenumber(eFermi,model='LowEnergy',g0prime=g0prime)
+        kf0 = FermiWavenumber(FermiLevel,model='LowEnergy',g0prime=g0prime)
 
         result = optimize.root_scalar(f,x0=kf0,x1=kf0*.9,rtol=1e-10).root
 
@@ -412,13 +414,14 @@ def DensityOfStates(E,model,g0prime=_c.g0prime):
     Parameters
     ----------
 
-    E:  array-like
+    E:  array-like, J
         Energy :math:`E` at which to evaluate density of states.
 
     model:      string
-                ``'LowEnergy'``: Linear approximation of dispersion.
+                ``'LowEnergy'``or ``'FullTightBinding'``
 
-                ``'FullTightBinding'``: Eigenvalues of tight-binding approximation. We use a closed form rather than finding eigenvalues of Hamiltonian to save time and avoid broadcasting issues.
+    g0prime:    scalar, J
+                The particle-hole asymmetry parameter :math:`\\gamma_0'`. Typically :math:`0.02\\gamma_0\\leq\\gamma_0'\\leq 0.2\\gamma_0`.
 
     Returns
     -------
@@ -549,10 +552,10 @@ def CarrierDensity(mu,T,model):
     Parameters
     ----------
 
-    mu: array-like
+    mu: array-like, J
         Chemical potential :math:`\\mu`
 
-    T:  scalar
+    T:  scalar, K
         Temperature :math:`T`
 
     Returns
@@ -580,8 +583,8 @@ def CarrierDensity(mu,T,model):
     if T<0:
         raise ValueError('Temperature T must be nonnegative')
     if T==0 and model=='LowEnergy':
-        eFermi=mu # chemical potential at T=0 is called Fermi level
-        n = (eFermi / (sc.hbar*_c.vF))**2 / np.pi
+        FermiLevel=mu # chemical potential at T=0 is called Fermi level
+        n = (FermiLevel / (sc.hbar*_c.vF))**2 / np.pi
         return n
 
     if T>0:
@@ -601,11 +604,11 @@ def ChemicalPotential(n,T=0,model='LowEnergy'):
     Parameters
     ----------
 
-    n:  array-like
-        Carrier density in units m^-2.
+    n:  array-like, m :sup:`-2`
+        Carrier density
 
-    T:  scalar
-        Temperature (K)
+    T:  scalar, K
+        Temperature
 
     Returns
     -------
@@ -637,6 +640,7 @@ def ChemicalPotential(n,T=0,model='LowEnergy'):
         # Use T=0 value to estimate start
         mu0 = ChemicalPotential(n,T=0,model=model)
 
+        # Add 0.1 eV offset to x1 because in case mu0=0, x0 and x1 would be equal
         result = optimize.root_scalar(f,x0=mu0,x1=mu0*1.1+0.1*sc.elementary_charge,
                                         rtol=1e-10).root
 
@@ -671,7 +675,7 @@ def Mobility(Te,mu0,T0):
 
     return mu
 
-def ScatteringRate(mobility,eFermi):
+def ScatteringRate(mobility,FermiLevel):
     '''
     Estimated DC scattering rate from mobility.
 
@@ -680,7 +684,7 @@ def ScatteringRate(mobility,eFermi):
 
     mobility:   scalar, mobility (m^2/V-s)
 
-    eFermi:     scalar, Fermi level (J)
+    FermiLevel:     scalar, Fermi level (J)
 
     Returns
     ----------
@@ -689,26 +693,33 @@ def ScatteringRate(mobility,eFermi):
     '''
 
     # Scattering time
-    tau = mobility*eFermi / (sc.elementary_charge*_c.vF**2)
+    tau = mobility*FermiLevel / (sc.elementary_charge*_c.vF**2)
 
     rate = 1/tau
     return rate
 
-def Polarizibility(q,omega,gamma,eFermi,T=0):
+def Polarizibility(q,omega,gamma,FermiLevel,T=0):
     '''
     The Polarizibility :math:`\\chi^0`` of graphene.
 
     Parameters
     ----------
 
-    q:      array-like, difference between scattered wavevector and incident
+    q:      array-like, rad/m
+            Difference between scattered wavevector and incident
 
-    omega:  array-like, frequency
+    omega:  array-like, rad/s
+            Angular frequency
 
-    gamma:  scalar, scattering rate due to mechanisms such as impurities (i.e. not Landau Damping)
-                    We use the Mermin-corrected Relaxation time approximation (Eqn 4.9 of Ref 1)
+    gamma:  scalar, rad/s
+            scattering rate due to mechanisms such as impurities (i.e. not Landau Damping)
+            We use the Mermin-corrected Relaxation time approximation (Eqn 4.9 of Ref 1)
 
-    eFermi: scalar, Fermi level of graphene.
+    FermiLevel: scalar, J
+                Fermi level of graphene.
+
+    T:  scalar, K
+        Temperature
 
     Notes
     -----
@@ -795,12 +806,12 @@ def Polarizibility(q,omega,gamma,eFermi,T=0):
         Equation 17 of Ref 2
         '''
 
-        prefactor = -DensityOfStates(eFermi,model='LowEnergy')
+        prefactor = -DensityOfStates(FermiLevel,model='LowEnergy')
 
-        kF = FermiWavenumber(eFermi, model='LowEnergy')
+        kF = FermiWavenumber(FermiLevel, model='LowEnergy')
 
         x = q / (2*kF)
-        zbar = sc.hbar*omega / (2*eFermi)
+        zbar = sc.hbar*omega / (2*FermiLevel)
 
         f = lambda x,zbar: (np.arcsin( (1-zbar)/x) + np.arcsin( (1+zbar)/x )
                         - ((zbar-1)/x)*np.sqrt(1 - ((zbar-1)/x)**2 )
@@ -813,14 +824,14 @@ def Polarizibility(q,omega,gamma,eFermi,T=0):
 
     elif gamma !=0:
         # Mermin-corrected Relaxation Time Approximation (Eqn 4.9 of Ref 1)
-        pol_complex_arg = Polarizibility(q,omega+1j*gamma,0,eFermi,T=0)
-        pol_0 = Polarizibility(q,0,0,eFermi,T=0)
+        pol_complex_arg = Polarizibility(q,omega+1j*gamma,0,FermiLevel,T=0)
+        pol_0 = Polarizibility(q,0,0,FermiLevel,T=0)
 
         numerator = (1 + 1j*gamma/omega) * pol_complex_arg
         denominator = 1 + ( 1j*gamma/omega * pol_complex_arg / pol_0 )
         return numerator / denominator
 
-def dPolarizibility(q,omega,gamma,eFermi,T,dvar,diff=1e-7):
+def dPolarizibility(q,omega,gamma,FermiLevel,T,dvar,diff=1e-7):
     '''
     Returns the derivative of the real part of the polarizibility at q, omega
     with respect to the chosen variable, dvar.
@@ -828,30 +839,36 @@ def dPolarizibility(q,omega,gamma,eFermi,T,dvar,diff=1e-7):
     Parameters
     ----------
 
-    q:      array-like,
+    q:      array-like, rad/m
+            Difference between scattered wavevector and incident
 
-    omega:
+    omega:  array-like, rad/s
+            Angular frequency
 
-    gamma:  scalar, the scattering rate in units (1/s)
+    gamma:  scalar, rad/s
+            The scattering rate
 
-    eFermi: scalar, the Fermi level (J)
+    FermiLevel: scalar, J
+                the Fermi level
 
-    T:      scalar, Temperature (K)
+    T:      scalar, K
+            Temperature
 
     dvar:   'omega': Take the partial wrt omega
             'q': Take the partial wrt q
 
     diff:   Size of finite different to use when computing the derivative.
             Method uses central difference.
+
     '''
 
     if dvar == 'omega':
-        P = lambda w: np.real(Polarizibility(q,w,gamma,eFermi,T))
+        P = lambda w: np.real(Polarizibility(q,w,gamma,FermiLevel,T))
         wa, wb = omega*(1-diff), omega*(1+diff)
         return (P(wb)-P(wa))/(2*omega*diff)
 
     elif dvar == 'q':
-        P = lambda qv: np.real(Polarizibility(qv,omega,gamma,eFermi,T))
+        P = lambda qv: np.real(Polarizibility(qv,omega,gamma,FermiLevel,T))
         qa,qb = q*(1-diff), q*(1+diff)
         return (P(qb)-P(qa))/(2*q*diff)
 
@@ -859,26 +876,25 @@ def dPolarizibility(q,omega,gamma,eFermi,T,dvar,diff=1e-7):
 # Optical Properties #
 ######################
 
-def OpticalConductivity(q,omega,gamma,eFermi,T,model=None):
+def OpticalConductivity(q,omega,gamma,FermiLevel,T,model=None):
     '''The diagonal conductivity of graphene :math:`\\sigma_{xx}`.
 
     Parameters
     ----------
 
-    q:          array-like
-                wavenumbers at which to evaluate the nonlocal conductivity.
-                Choose q=0 for the LOCAL conductivity.
+    q:      array-like, rad/m
+            Wavenumber
 
-    omega:      array-like
-                angular frequency
+    omega:      array-like, rad/s
+                Angular frequency
 
-    eFermi:     scalar
-                the Fermi energy (J)
+    FermiLevel:     scalar, J
+                the Fermi energy
 
-    gamma:      scalar
+    gamma:      scalar, rad/s
                 scattering rate
 
-    T:          scalar
+    T:          scalar, K
                 Temperature
 
     model:      string
@@ -906,9 +922,9 @@ def OpticalConductivity(q,omega,gamma,eFermi,T,model=None):
         >>> eF = 0.4 * elementary_charge
         >>> g = 0.012 * elementary_charge / hbar
         >>> w = np.linspace(0.01,3,num=150) / (hbar/eF)
-        >>> s_0K_0g = mlg.OpticalConductivity(q=0,omega=w,gamma=0,eFermi=eF,T=0)
-        >>> s_0K_12g = mlg.OpticalConductivity(q=0,omega=w,gamma=g,eFermi=eF,T=0.01)
-        >>> s_300K_12g = mlg.OpticalConductivity(q=0,omega=w,gamma=g,eFermi=eF,T=300)
+        >>> s_0K_0g = mlg.OpticalConductivity(q=0,omega=w,gamma=0,FermiLevel=eF,T=0)
+        >>> s_0K_12g = mlg.OpticalConductivity(q=0,omega=w,gamma=g,FermiLevel=eF,T=0.01)
+        >>> s_300K_12g = mlg.OpticalConductivity(q=0,omega=w,gamma=g,FermiLevel=eF,T=300)
         >>> fig, (re_ax, im_ax) = plt.subplots(1,2,figsize=(11,4))
         >>> s_Re = np.real(s_0K_0g)
         >>> s_Im = np.imag(s_0K_0g)
@@ -944,15 +960,17 @@ def OpticalConductivity(q,omega,gamma,eFermi,T,model=None):
     -----
     The optical conductivity :math:`\\overleftrightarrow{\\sigma}(q,\\omega)` 
     relates the surface current :math:`\\mathbf K(\\omega)` 
-    to an applied electric field :math:`\\mathbf E(\\omega)`
+    to an applied electric field :math:`\\mathbf E(\\omega)`.
+    The fully general, anisotropic, nonlocal expression is given by
 
     .. math::
 
         \\mathbf K(\\omega)=\\int \\overleftrightarrow\\sigma(q,\\omega)\\mathbf E(\\omega) dq
     
 
-    Here, :math:`\\omega` refers to the frequency and :math:`q` refers to the scattering wavevector. 
-    In many cases, :math:`\\overleftrightarrow{\\sigma}` is isotropic, 
+    Here, :math:`\\omega` refers to the frequency and :math:`q` refers to the scattering wavevector.
+    The above expression is rarely needed.
+    In most cases, :math:`\\overleftrightarrow{\\sigma}` is isotropic, 
     so the above equation can be reduced to a scalar equation
 
     .. math::
@@ -965,16 +983,34 @@ def OpticalConductivity(q,omega,gamma,eFermi,T,model=None):
     .. math::
         \\sigma(q,\\omega)=\\frac{ie^2\\omega}{q^2}\\chi^0(q,\\omega).
     
-    If ``q`` is nonzero, this form is used.
-    However, it is common to use simpler limiting cases of this expression.
-    The local conductivity (``q=0``) is the one which is most familiar 
+    where :math:`\\chi^0` is the Polarizibility. If ``q`` is nonzero, this form is used.
+    However, it is common to use a simpler limiting cases of this expression.
+    The local conductivity (called when ``q==0``) is the one which is most familiar 
     and it relates the surface current to the electric field linearly
     
     .. math::
 
         \\mathbf K(\\omega)=\\sigma(\\omega)\\mathbf E
 
-    It can be found from the nonlocal conductivity by taking the limit :math:`\\lim_{q\\to 0}\\sigma(q,\\omega)=\\sigma(\\omega)`.
+    It can be found from the nonlocal conductivity by taking the limit :math:`\\lim_{q\\to 0}\\sigma(q,\\omega)=\\sigma(\\omega)`
+    and takes the form :math:`\\sigma(\\omega)=\\sigma_{intra}(\\omega)+\\sigma_{inter}(\\omega)`, 
+    where the intraband and interband components are given by
+
+    .. math::
+
+        \\sigma_{intra}(\\omega) = \\frac{2ie^2k_BT}{\\pi\\hbar^2(\\omega+i\\gamma)}\\ln\\left [ 2 \\cosh \\frac{E_F}{2k_BT} \\right ]
+
+    and 
+
+    .. math::
+
+        \\sigma_{inter}(\\omega) = \\frac{e^2}{4\\hbar}\\left [ H(\\hbar\\omega/2) + \\frac{4i}{\\pi}\\hbar ( \\omega +i \\gamma )\\int_0^\\infty \\frac{H( \\epsilon )-H(\\hbar\\omega /2)}{\\hbar^2(\\omega +i\\gamma )^2-4\\epsilon^2} d\\epsilon\\right ]
+    
+    where
+
+    .. math::
+
+        H(\\epsilon) = f(-\\epsilon)-f(\\epsilon) = \\frac{\\sinh(\\epsilon/k_BT)}{\\cosh(E_F/k_BT) + \\cosh(\\epsilon/k_BT)}
 
     References
     ----------
@@ -996,12 +1032,12 @@ def OpticalConductivity(q,omega,gamma,eFermi,T,model=None):
             ### Intraband Contribution ###
 
             # Using np.logaddexp() avoids the large cosh in ln( cosh(1/T) )
-            x = eFermi / (2*sc.k*T)
+            x = FermiLevel / (2*sc.k*T)
             intra = lambda w: intra_pre * ( 1 / (w + 1j*gamma) ) * np.logaddexp(x,-x)
 
             ### Interband Contribution ###
 
-            H = lambda energy: sd.FermiDirac(-energy-eFermi,T) - sd.FermiDirac(energy-eFermi,T)
+            H = lambda energy: sd.FermiDirac(-energy-FermiLevel,T) - sd.FermiDirac(energy-FermiLevel,T)
 
             integrand = lambda energy,w: ( H(energy) - H(sc.hbar*w/2) ) / (sc.hbar**2 * (w + 1j*gamma)**2 - 4 * energy**2)
 
@@ -1012,8 +1048,8 @@ def OpticalConductivity(q,omega,gamma,eFermi,T,model=None):
                     integrand_re = lambda e: np.real(integrand(e,frequency))
                     integrand_im = lambda e: np.imag(integrand(e,frequency))
 
-                    result[i] =(     integrate.quad(integrand_re,0,10*eFermi,points=(eFermi/sc.hbar,2*eFermi/sc.hbar))[0]
-                                + 1j*integrate.quad(integrand_im,0,10*eFermi,points=(eFermi/sc.hbar,2*eFermi/sc.hbar))[0] )
+                    result[i] =(     integrate.quad(integrand_re,0,10*FermiLevel,points=(FermiLevel/sc.hbar,2*FermiLevel/sc.hbar))[0]
+                                + 1j*integrate.quad(integrand_im,0,10*FermiLevel,points=(FermiLevel/sc.hbar,2*FermiLevel/sc.hbar))[0] )
 
                 return result
 
@@ -1023,32 +1059,44 @@ def OpticalConductivity(q,omega,gamma,eFermi,T,model=None):
             conductivity= intra(omega) + inter(omega)
 
         if T==0:
-            intra = lambda w: 1j*_c.sigma_0 * 4*eFermi / (sc.pi*sc.hbar* (w + 1j*gamma))
+            intra = lambda w: 1j*_c.sigma_0 * 4*FermiLevel / (sc.pi*sc.hbar* (w + 1j*gamma))
 
-            inter = lambda w: _c.sigma_0 * ( np.heaviside(sc.hbar*w - 2*eFermi,0.5) + 
-                                            (1j/sc.pi) * np.log(np.abs((2*eFermi-sc.hbar*w)/(2*eFermi+sc.hbar*w))))
+            inter = lambda w: _c.sigma_0 * ( np.heaviside(sc.hbar*w - 2*FermiLevel,0.5) + 
+                                            (1j/sc.pi) * np.log(np.abs((2*FermiLevel-sc.hbar*w)/(2*FermiLevel+sc.hbar*w))))
 
             conductivity = intra(omega) + inter(omega)
 
     # Nonlocal case
     else:
         if T==0:
-            conductivity = 1j*sc.elementary_charge**2 * (omega / q**2) * Polarizibility(q,omega,gamma,eFermi,T)
+            conductivity = 1j*sc.elementary_charge**2 * (omega / q**2) * Polarizibility(q,omega,gamma,FermiLevel,T)
 
         else:
             pass
 
     return conductivity
 
-def OpticalConductivityMatrix(q,omega,gamma, eFermi,T,mu0,mu0T):
+def OpticalConductivityMatrix(q,omega,gamma, FermiLevel,T):
     '''
     Returns the conductivity matrix of monolayer graphene.
 
     Parameters
     ----------
 
-    omega:
+    q:      array-like, rad/m
+            Wavenumber
 
+    omega:  array-like, rad/s
+            Angular frequency
+
+    FermiLevel:     scalar, J
+                the Fermi energy
+
+    gamma:      scalar, rad/s
+                scattering rate
+
+    T:          scalar, K
+                Temperature
     Returns
     ----------
 
@@ -1057,12 +1105,12 @@ def OpticalConductivityMatrix(q,omega,gamma, eFermi,T,mu0,mu0T):
     '''
 
 
-    conductivity_matrix = np.array([[OpticalConductivity(q,omega,gamma,eFermi,T),0],
-                                    [0,OpticalConductivity(q,omega,gamma,eFermi,T)]])
+    conductivity_matrix = np.array([[OpticalConductivity(q,omega,gamma,FermiLevel,T),0],
+                                    [0,OpticalConductivity(q,omega,gamma,FermiLevel,T)]])
 
     return conductivity_matrix
 
-def Permittivity(omega,eFermi,T, gamma=None,epsR=None,model=None):
+def Permittivity(q, omega,FermiLevel,T, gamma=None,epsR=None,model=None):
     '''
     Returns the in-plae permittivity of graphene.
 
@@ -1071,7 +1119,14 @@ def Permittivity(omega,eFermi,T, gamma=None,epsR=None,model=None):
     Parameters
     ----------
 
-    epsR:       scalar, background relative permittivity
+    q:      array-like, rad/m
+            Wavenumber
+
+    omega:  array-like, rad/s
+            Angular frequency
+    
+    epsR:   scalar, unitless
+            background relative permittivity
 
     References
     ----------
@@ -1087,7 +1142,7 @@ def Permittivity(omega,eFermi,T, gamma=None,epsR=None,model=None):
         '''
         x1 = sc.elementary_charge
         x2 = sc.hbar
-        x3 = eFermi
+        x3 = FermiLevel
         x4 = _c.vF
         x5 = Mobility(T,mu0,mu0T) # mobility at the new temperature
         x6 = epsR
@@ -1106,11 +1161,11 @@ def Permittivity(omega,eFermi,T, gamma=None,epsR=None,model=None):
         return eps
 
     else:
-        eps = 1 + 1j*OpticalConductivity(0,omega,gamma,eFermi,T)/(omega*sc.epsilon_0)
+        eps = 1 + 1j*OpticalConductivity(q,omega,gamma,FermiLevel,T,model)/(omega*sc.epsilon_0)
 
     return eps
 
-def FresnelReflection(kpar,omega,gamma,eFermi,T,eps1,eps2,polarization):
+def FresnelReflection(q,omega,gamma,FermiLevel,T,eps1,eps2,polarization):
     '''
     The Fresnel Reflection coefficients of light incident from above (medium 1, eps1).
 
@@ -1119,24 +1174,66 @@ def FresnelReflection(kpar,omega,gamma,eFermi,T,eps1,eps2,polarization):
     Parameters
     ----------
 
-    kp:             Parallel (in-plane) momentum of indicent light.
+    q:      array-like, rad/m
+            Wavenumber at which to evaluate FresnelReflection.
+            In-plane momentum of incident light.
 
-    omega:          Frequency of incident light.
+    omega:  array-like, rad/s
+            Angular frequency of incident light.
 
-    eps1, eps2:     Permittivities above and below graphene, respectively.
-                    Could also be made callable such that eps1=eps1(kpar,omega)
+    eps1:   scalar, unitless
+            Permittivity in upper half-space
 
-    polarization:   's'/'TE' or 'p'/'TM' for s- or p-polarization.
+    eps2:   scalar, unitless
+            Permittivity in lower half-space
+
+    polarization:   string
+        's'/'TE' or 'p'/'TM' for s- or p-polarization.
+
+    Examples
+    --------
+
+    Plot the TM polarized Fresnel Reflection coefficient. This will highlight the plasmon.
+    Replicates Fig. 5.2 in Ref [1].
+
+    .. plot::
+
+        >>> import matplotlib.pyplot as plt
+        >>> import matplotlib.cm as cm
+        >>> from graphenemodeling.graphene import monolayer as mlg
+        >>> from scipy.constants import elementary_charge, hbar
+        >>> eV = elementary_charge
+        >>> FermiLevel = 0.4 * eV
+        >>> gamma = 0.012 * eV / hbar
+        >>> kF = mlg.FermiWavenumber(FermiLevel,model='LowEnergy')
+        >>> q = np.linspace(1e-2,3,num=200) * kF
+        >>> w = np.linspace(1e-2,3,num=200) * FermiLevel / hbar
+        >>> fresnelTM = mlg.FresnelReflection(q,w[:,np.newaxis],gamma,FermiLevel,T=0,
+        ...                                     eps1=1,eps2=1,
+        ...                                     polarization='TM')
+        >>> fig, ax = plt.subplots(figsize=(6,6))
+        >>> ax.imshow(-np.imag(fresnelTM),
+        ...             extent=(q[0]/kF,q[-1]/kF,hbar*w[0]/FermiLevel,hbar*w[-1]/FermiLevel),
+        ...             origin='lower',aspect='auto',cmap=cm.hot,vmin=-16,vmax=0)
+        >>> ax.set_xlabel('$q/k_F$')
+        >>> ax.set_ylabel('$\\hbar\\omega/E_F$')
+        >>> ax.set_ylim(0,3)
+        >>> ax.set_xlim(0,3)
+        >>> fig.suptitle('Fresnel Reflection Coefficient (TM)')
+        >>> plt.show()
 
     References
     ----------
 
-    [1] Christensen Thesis 2017
+    [1] Christensen, T. (2017).
+    From Classical to Quantum Plasmonics in Three and Two Dimensions (Cham: Springer International Publishing).
+    http://link.springer.com/10.1007/978-3-319-48562-1.
+
     '''
 
-    kperp1, kperp2 = np.sqrt(eps1*(omega/sc.speed_of_light)**2 - kpar**2 + 1e-9*1j), np.sqrt(eps2*(omega/sc.speed_of_light)**2 - kpar**2 + 1e-9*1j)
+    kperp1, kperp2 = np.sqrt(eps1*(omega/sc.speed_of_light)**2 - q**2 + 1e-9*1j), np.sqrt(eps2*(omega/sc.speed_of_light)**2 - q**2 + 1e-9*1j)
 
-    sigma = OpticalConductivity(kpar,omega,gamma,eFermi,T)
+    sigma = OpticalConductivity(q,omega,gamma,FermiLevel,T)
 
     if polarization=='p' or polarization=='TM':
         numerator   = eps2*kperp1 - eps1*kperp2 + ( sigma*kperp1*kperp2 / (sc.epsilon_0*omega) )
@@ -1148,7 +1245,7 @@ def FresnelReflection(kpar,omega,gamma,eFermi,T,eps1,eps2,polarization):
 
     return numerator / denominator
 
-def LocalDensityOfStates(d,omega,gamma,eFermi,T):
+def LocalDensityOfStates(d,omega,gamma,FermiLevel,T):
     '''
     The LDOS a distance d above a plane of graphene.
 
@@ -1170,103 +1267,31 @@ def LocalDensityOfStates(d,omega,gamma,eFermi,T):
 
     for i, d0 in np.ndenumerate(d):
         k0w = (omega/sc.speed_of_light)
-        Im_rp      = lambda kpar: np.imag( FresnelReflection(kpar,omega,gamma,eFermi,T,1,1,'p') )
+        Im_rp      = lambda q: np.imag( FresnelReflection(q,omega,gamma,FermiLevel,T,1,1,'p') )
 
-        integrand = lambda kpar: (kpar**2/k0w**3)*Im_rp(kpar)*np.exp(-2*kpar*d0)
+        integrand = lambda q: (q**2/k0w**3)*Im_rp(q)*np.exp(-2*q*d0)
 
         a,b = 1e-3, np.abs(_c.K) # Increasing this bound does not lead to more convergence
 
-        k_plasmon=InversePlasmonDispersion(omega,gamma,eFermi,1,1,T,model='nonlocal')
+        q_plasmon=InversePlasmonDispersion(omega,gamma,FermiLevel,1,1,T,model='nonlocal')
 
         integral[i] = integrate.quad(integrand,a,b,
-                                    points=(k_plasmon),limit=100)[0]
+                                    points=(q_plasmon),limit=100)[0]
 
     return ldos0 * integral      
 
-def OpticalResponseBound(omega,gamma,eFermi,T,d=None,method='svd',restype='material'):
-    '''
-    A general material optical response bound independent of geometrical parameters.
-
-    See equation 6 of Ref 1 (and remove the beta).
-
-    Assumes a linear conductivity model K=sigma * E, could be generalized
-    to K = L E where L is a differential operator.
-
-    For LDOS options, assumes a planar geometry. See Ref 1 for solid angle correction for nonplanar
-
-    Parameters
-    ----------
-
-    omega:      array-like, the frequency range of interest (rad/s)
-
-    gamma:      scalar, the scattering rate (rad/s)
-
-    eFermi:     scalar, Fermi level (J)
-
-    T:          scalar, Temperature (K)
-
-    d:          scalar, Distance from graphene (m), if using LDOS restype (see below)
-
-    method:     'svd': Use singular value decomposition version of formula
-                'scalar': Uses the simplified scalar version.
-
-    restype:    Bound on response types given below
-                'material': Instrinsic material FOM
-                'CSabs': Absorption cross section / area
-                'CSext': Extinction cross section / area
-                'CSsca': Scattering cross section / area
-                'LDOStot': Total LDOS / Free space LDOS
-                'LDOSnrad': Nonradiative LDOS / Free space LDOS
-                'LDOSrad': Radiative LDOS / Free space LDOS
-
-
-    References
-    ----------
-
-    [1] Miller et al. 2017
-        URL: http://pubs.acs.org/doi/10.1021/acs.nanolett.7b02007
-    '''
-
-    if np.all(d):
-        k0 = omega/sc.speed_of_light
-        LDOSprop = 3 / (8 * (k0*d)**4)
-
-    prop = dict({'material':1,
-                'CSabs':1, 'CSext': 1, 'CSsca': 1/4,
-                'LDOStot':1*LDOSprop,'LDOSnrad':1*LDOSprop,'LDOSrad':LDOSprop/4})
-
-    if method == 'scalar':
-        sigma = OpticalConductivity(0,omega,gamma,eFermi,T)
-
-        bound = Z_0 * np.abs(sigma)**2 / np.real(sigma)
-
-    elif method == 'svd':
-        bound = np.empty_like(omega)
-
-        for i, w in np.ndenumerate(omega):
-            s = OpticalConductivityMatrix(0,w,gamma,eFermi,T)
-            s_dag = np.conj(np.transpose(s))
-            s_re_inv = np.linalg.inv(np.real(s))
-            prod = np.dot(s_dag,np.dot(s_re_inv,s))
-            two_norm= np.linalg.svd(prod)[1][0]
-            bound[i] = Z_0*two_norm
-
-
-
-    return prop[restype] * bound
-
 #####################
 # Phonon Properties #
 #####################
 
-def PhononSelfEnergy(self):
+def PhononSelfEnergy():
     pass
 
 ##############
 # Plasmonics #
 ##############
 
-def PlasmonDispersion(q,gamma,eFermi,eps1,eps2,T,model):
+def PlasmonDispersion(q,gamma,FermiLevel,eps1,eps2,T,model):
     '''
     Returns the nonretarded plasmon dispersion relations E(q) for a surface
     plasmon in an infinite sheet of graphene sandwiched between two
@@ -1277,11 +1302,14 @@ def PlasmonDispersion(q,gamma,eFermi,eps1,eps2,T,model):
     Parameters
     ----------
 
-    q:  array-like
+    q:  array-like, rad/m
         Wavenumber of the plasmon
 
-    eps1,eps2:  scalar
-        the relative permittivity of upper and lower half-space respectively.
+    eps1:   scalar, unitless
+            Permittivity in upper half-space
+
+    eps2:  scalar, unitless
+            Permittivity in lower half-space
 
     model:  string
         'intra' for intraband dispersion,
@@ -1401,18 +1429,18 @@ def PlasmonDispersion(q,gamma,eFermi,eps1,eps2,T,model):
 
     # Analytical expression in intraband approximation
     if model=='intra':
-        radical = q * sc.elementary_charge**2 * eFermi / (2*sc.pi * sc.epsilon_0 * epsavg)
+        radical = q * sc.elementary_charge**2 * FermiLevel / (2*sc.pi * sc.epsilon_0 * epsavg)
         return (1/sc.hbar) * np.sqrt(radical)
 
     if model=='local':
         omega = np.empty_like(q)
 
-        sigma = lambda w: OpticalConductivity(0,w,gamma,eFermi,T=0)
+        sigma = lambda w: OpticalConductivity(0,w,gamma,FermiLevel,T=0)
 
         for i,q0 in np.ndenumerate(q):
             root_eqn = lambda w: 1 - np.imag(sigma(w))*q0 / (2*sc.epsilon_0*epsavg*w)
 
-            a, b = PlasmonDispersion(q0,gamma,eFermi,eps1,eps2,T,model='intra'), 1e-8
+            a, b = PlasmonDispersion(q0,gamma,FermiLevel,eps1,eps2,T,model='intra'), 1e-8
             omega[i] = optimize.brentq(root_eqn,a,b)
 
         return omega
@@ -1420,19 +1448,18 @@ def PlasmonDispersion(q,gamma,eFermi,eps1,eps2,T,model):
     if model=='nonlocal':
         omega = np.empty_like(q)
 
-        kF = FermiWavenumber(eFermi,model='LowEnergy')
+        kF = FermiWavenumber(FermiLevel,model='LowEnergy')
 
         for i, q0 in np.ndenumerate(q):
-            root_eqn = lambda w: PlasmonDispersionRoot(q0,w,gamma,eFermi,eps1,eps2,T=0)
+            root_eqn = lambda w: PlasmonDispersionRoot(q0,w,gamma,FermiLevel,eps1,eps2,T=0)
             
             # Frequency is definitely below 1,1 intraband dispersion
-            b = PlasmonDispersion(q0,gamma,eFermi,1,1,T,model='intra')
+            b = PlasmonDispersion(q0,gamma,FermiLevel,1,1,T,model='intra')
 
             # Frequency is definitely above the minimum which should be <0
-            a = optimize.minimize_scalar(root_eqn,bounds=((eFermi/sc.hbar)*q0/kF,b),method='bounded').x
+            a = optimize.minimize_scalar(root_eqn,bounds=((FermiLevel/sc.hbar)*q0/kF,b),method='bounded').x
             
             if root_eqn(a) > 0:
-                #warnings.warn("Monolayer.PlasmonDispersion(model='nonlocal'): No root exists for q=%.5f" % (q0))
                 omega[i]=0
             else:
                 root_eqn_abs= lambda w: np.abs(root_eqn(w))
@@ -1443,7 +1470,7 @@ def PlasmonDispersion(q,gamma,eFermi,eps1,eps2,T,model):
 
         return omega
 
-def PlasmonDispersionRes(q,gamma,eFermi,eps1,eps2,T,exp_res=1):
+def PlasmonDispersionRes(q,gamma,FermiLevel,eps1,eps2,T,exp_res=1):
     '''
     Uses the FresnelReflection coefficients to numerically search for the 
     plasmon dispersion
@@ -1451,6 +1478,12 @@ def PlasmonDispersionRes(q,gamma,eFermi,eps1,eps2,T,exp_res=1):
     Parameters
     ----------
 
+    eps1:   scalar, unitless
+            Permittivity in upper half-space
+
+    eps2:   scalar, unitless
+            Permittivity in lower half-space
+
     exp_res:    expected number of resonances
     '''
     q = np.atleast_1d(q)
@@ -1460,12 +1493,12 @@ def PlasmonDispersionRes(q,gamma,eFermi,eps1,eps2,T,exp_res=1):
 
     for i,q0 in np.ndenumerate(q):
         w1 = q0*_c.vF
-        w2 = PlasmonDispersion(q0,gamma,eFermi,eps1,eps2,T,model='intra')
+        w2 = PlasmonDispersion(q0,gamma,FermiLevel,eps1,eps2,T,model='intra')
         w0 = (w2+w1)/2
         # omega=np.linspace(q0*_c.vF,2*q0*_c.vF,num=300)
         omega=np.linspace(w1,w2,num=300)
 
-        y = np.imag(FresnelReflection(q0,omega,gamma,eFermi,T,eps1,eps2,'TM'))
+        y = np.imag(FresnelReflection(q0,omega,gamma,FermiLevel,T,eps1,eps2,'TM'))
 
         p0=[w0,0.1*w0,10]
 
@@ -1478,20 +1511,30 @@ def PlasmonDispersionRes(q,gamma,eFermi,eps1,eps2,T,exp_res=1):
 
     return np.abs(pFit)
 
-def InversePlasmonDispersion(omega,gamma,eFermi,eps1,eps2,T,model):
+def InversePlasmonDispersion(omega,gamma,FermiLevel,eps1,eps2,T,model):
     '''
     Returns the wavenumber of a plasmon given the frequency.
 
     Useful when determining the wavelength of a plasmon excited by light.
+
+    Parameters
+    ----------
+
+    eps1:   scalar, unitless
+            Permittivity in upper half-space
+
+    eps2:   scalar, unitless
+            Permittivity in lower half-space
+
     '''
 
-    kF = FermiWavenumber(eFermi,model='LowEnergy')
+    kF = FermiWavenumber(FermiLevel,model='LowEnergy')
 
     cutoff = 4*kF
     q = np.empty_like(omega)
 
     for i, omega in np.ndenumerate(omega):
-        root_eqn = lambda q: np.abs( omega - PlasmonDispersion(q,gamma,eFermi,eps1,eps2,T,model) )
+        root_eqn = lambda q: np.abs( omega - PlasmonDispersion(q,gamma,FermiLevel,eps1,eps2,T,model) )
 
         reps = 1
         while reps < 5:
@@ -1504,20 +1547,38 @@ def InversePlasmonDispersion(omega,gamma,eFermi,eps1,eps2,T,model):
 
     return q
 
-def PlasmonDispersionRoot(q,omega,gamma,eFermi, eps1,eps2 ,T):
+def PlasmonDispersionRoot(q,omega,gamma,FermiLevel, eps1,eps2 ,T):
     '''
     The equation used for numerically solving the plasmon dispersion in the nonretarded regime.
+
+    Parameters
+    ----------
+
+    eps1:   scalar, unitless
+            Permittivity in lower half-space
+
+    eps2:   scalar, unitless
+            Permittivity in upper half-space
     '''
 
     epsavg = (eps1+eps2)/2
 
-    return 1 - np.imag(OpticalConductivity(q,omega,gamma,eFermi,T))*q / (2*sc.epsilon_0*epsavg*omega)
+    return 1 - np.imag(OpticalConductivity(q,omega,gamma,FermiLevel,T))*q / (2*sc.epsilon_0*epsavg*omega)
 
-def PlasmonDispersionLoss(omega,gamma,eFermi,eps1,eps2,T,model):
+def PlasmonDispersionLoss(omega,gamma,FermiLevel,eps1,eps2,T,model):
     '''
     The loss of the plasmon wavenumber q=q1+iq2. Returns q2. Equation 15 of Ref [1]
     with tau = infinity (or gamma = 0). Assumes q2<<q1
 
+    Parameters
+    ----------
+
+    eps1:   scalar, unitless
+            Permittivity in upper half-space
+
+    eps2:   scalar, unitless
+            Permittivity in lower half-space
+
     References
     ----------
 
@@ -1525,13 +1586,13 @@ def PlasmonDispersionLoss(omega,gamma,eFermi,eps1,eps2,T,model):
     '''
     
     if model == 'nonlocal':
-        q1 = InversePlasmonDispersion(omega,gamma,eFermi,eps1,eps2,T,model)
+        q1 = InversePlasmonDispersion(omega,gamma,FermiLevel,eps1,eps2,T,model)
 
-        pol = Polarizibility(q1,omega,gamma,eFermi,T=0)
-        pol0= Polarizibility(q1,1e-9,gamma,eFermi,T=0)
+        pol = Polarizibility(q1,omega,gamma,FermiLevel,T=0)
+        pol0= Polarizibility(q1,1e-9,gamma,FermiLevel,T=0)
 
-        dpolq = dPolarizibility(q1,omega,gamma,eFermi,T,dvar='q')
-        dpolw = dPolarizibility(q1,omega,gamma,eFermi,T,dvar='omega')
+        dpolq = dPolarizibility(q1,omega,gamma,FermiLevel,T,dvar='q')
+        dpolw = dPolarizibility(q1,omega,gamma,FermiLevel,T,dvar='omega')
 
         numerator = np.imag(-pol) + gamma * (-1)*dpolw + (gamma/omega) * np.real(-pol * (1- (pol/pol0)))
         denominator = (1/q1) * np.real(-pol) - (-1)*dpolq
@@ -1540,22 +1601,31 @@ def PlasmonDispersionLoss(omega,gamma,eFermi,eps1,eps2,T,model):
 
     return q2
 
-def dPlasmonDispersion(q,gamma,eFermi,eps1,eps2,T,model,dvar=None,diff=1e-7):
+def dPlasmonDispersion(q,gamma,FermiLevel,eps1,eps2,T,model,dvar=None,diff=1e-7):
     '''
     Derivative of plasmon frequency with respect to dvar.
 
     Parameters
     ----------
 
-    q:      array-like,
+    q:      array-like, rad/m
 
-    omega:
+    omega:  array-like, rad/s
 
-    gamma:  scalar, the scattering rate in units (1/s)
+    gamma:  scalar, rad/s
+            the scattering rate in units (1/s)
 
-    eFermi: scalar, the Fermi level (J)
+    FermiLevel: scalar, J
+                the Fermi level
 
-    T:      scalar, Temperature (K)
+    eps1:   scalar, unitless
+            Permittivity in upper half-space
+
+    eps2:   scalar, unitless
+            Permittivity in lower half-space
+
+    T:      scalar, K
+            Temperature
 
     dvar:   'omega': Take the partial wrt omega
             'q': Take the partial wrt q
@@ -1564,12 +1634,12 @@ def dPlasmonDispersion(q,gamma,eFermi,eps1,eps2,T,model,dvar=None,diff=1e-7):
             Method uses central difference.
     '''
 
-    if dvar == 'eFermi':
+    if dvar == 'FermiLevel':
         result = np.empty_like(q)
         for i, q0 in np.ndenumerate(q):
             w = lambda eF: PlasmonDispersion(q0,gamma,eF,eps1,eps2,T,model)
-            e1, e2 = eFermi*(1-diff), eFermi*(1+diff)
-            result[i] = (w(e2)-w(e1))/(2*eFermi*diff)
+            e1, e2 = FermiLevel*(1-diff), FermiLevel*(1+diff)
+            result[i] = (w(e2)-w(e1))/(2*FermiLevel*diff)
 
         return result
 
@@ -1578,7 +1648,7 @@ def dPlasmonDispersion(q,gamma,eFermi,eps1,eps2,T,model,dvar=None,diff=1e-7):
 
     pass
 
-def DipoleDecayRate(z,omega,gamma,eFermi,T,eps1,eps2):
+def DipoleDecayRate(z,omega,gamma,FermiLevel,T,eps1,eps2):
     '''
     Decay rate of a dipole emitter placed near graphene.
     Right now, the dipole only points perpendicular.
@@ -1587,6 +1657,15 @@ def DipoleDecayRate(z,omega,gamma,eFermi,T,eps1,eps2):
 
     Eqn 5 in the SM of Ref 1.
 
+    Parameters
+    ----------
+
+    eps1:   scalar, unitless
+            Permittivity in upper half-space
+
+    eps2:   scalar, unitless
+            Permittiviy in lower half-space
+
     References
     ----------
 
@@ -1603,17 +1682,17 @@ def DipoleDecayRate(z,omega,gamma,eFermi,T,eps1,eps2):
 
     for i, w in np.ndenumerate(omega):
 
-        kperp   = lambda kpar: np.sqrt(eps1*(w/sc.speed_of_light)**2 - kpar**2)
-        rp      = lambda kpar: FresnelReflection(kpar,w,gamma,eFermi,T,eps1,eps2,'p')
-        perpterm = lambda kpar: 2*np.abs(d[2])**2 * kpar**2 * rp(kpar)
+        kperp   = lambda q: np.sqrt(eps1*(w/sc.speed_of_light)**2 - q**2)
+        rp      = lambda q: FresnelReflection(q,w,gamma,FermiLevel,T,eps1,eps2,'p')
+        perpterm = lambda q: 2*np.abs(d[2])**2 * q**2 * rp(q)
 
-        integrand = lambda kpar: np.real( (kpar - 1e-9*1j) * np.real( perpterm(kpar-1e-9*1j) * np.exp(2*1j*kperp(kpar-1e-9*1j)*z) / kperp(kpar-1e-9*1j) ) )
+        integrand = lambda q: np.real( (q - 1e-9*1j) * np.real( perpterm(q-1e-9*1j) * np.exp(2*1j*kperp(q-1e-9*1j)*z) / kperp(q-1e-9*1j) ) )
 
         b = np.abs(_c.K) # Increasing this bound does not lead to more convergence
-        kpar_pol = np.sqrt(eps1) * (w/sc.speed_of_light)
-        k_plasmon=InversePlasmonDispersion(w,gamma,eFermi,eps1,eps2,T,model='nonlocal')
+        q_pol = np.sqrt(eps1) * (w/sc.speed_of_light)
+        q_plasmon=InversePlasmonDispersion(w,gamma,FermiLevel,eps1,eps2,T,model='nonlocal')
 
         integral[i] = integrate.quad(integrand,1e-3,b,
-                                    points=(kpar_pol,k_plasmon),limit=100)[0]
+                                    points=(q_pol,q_plasmon),limit=100)[0]
 
     return dipole.DecayRate(omega,d) + (1/sc.hbar) * integral
